//[mahjong-utils](../../../index.md)/[mahjongutils.models.hand](../index.md)/[KokushiHandPattern](index.md)/[KokushiHandPattern](-kokushi-hand-pattern.md)

# KokushiHandPattern

[common]\
constructor(yaochu: [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Tile](../../mahjongutils.models/-tile/index.md)&gt;, repeated: [Tile](../../mahjongutils.models/-tile/index.md)?, remaining: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Tile](../../mahjongutils.models/-tile/index.md)&gt;)
